@@ -1,6 +1,9 @@
 import logging
 from urllib.parse import urlparse
 
+import requests
+from requests.packages.urllib3.exceptions import InsecureRequestWarning
+
 from instagrapi.mixins.account import AccountMixin
 from instagrapi.mixins.album import DownloadAlbumMixin, UploadAlbumMixin
 from instagrapi.mixins.auth import LoginMixin
@@ -32,6 +35,8 @@ from instagrapi.mixins.totp import TOTPMixin
 from instagrapi.mixins.user import UserMixin
 from instagrapi.mixins.video import DownloadVideoMixin, UploadVideoMixin
 
+requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
+
 
 class Client(
     PublicRequestMixin,
